==> okteta_0.25.5.orig.tar.xz: okteta-0.25.5/kasten/controllers/view/filter/filtertoolviewfactory.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "filtertoolviewfactory.h"

// lib
#include "filtertoolview.h"
#include "filtertool.h"
// KF5
#include <KLocalizedString>

namespace Kasten {

FilterToolViewFactory::FilterToolViewFactory() = default;

FilterToolViewFactory::~FilterToolViewFactory() = default;

QString FilterToolViewFactory::iconName() const { return QStringLiteral("okteta"); }
QString FilterToolViewFactory::title()       const { return i18nc("@title:window", "Binary Filter"); }
QString FilterToolViewFactory:: id()      const { return QStringLiteral("org.kde.okteta.FilterToolView"); }
SidePosition FilterToolViewFactory::defaultPosition() const { return BottomSidePosition; }

AbstractToolView* FilterToolViewFactory::create(AbstractTool* tool)
{
    return new FilterToolView(qobject_cast<FilterTool*>(tool));
}

}

==> okteta_0.26.3.orig.tar.xz: okteta-0.26.3/kasten/controllers/view/filter/filtertoolviewfactory.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "filtertoolviewfactory.hpp"

// lib
#include "filtertoolview.hpp"
#include "filtertool.hpp"
// KF
#include <KLocalizedString>

namespace Kasten {

FilterToolViewFactory::FilterToolViewFactory() = default;

FilterToolViewFactory::~FilterToolViewFactory() = default;

QString FilterToolViewFactory::iconName() const { return QStringLiteral("okteta"); }
QString FilterToolViewFactory::title()       const { return i18nc("@title:window", "Binary Filter"); }
QString FilterToolViewFactory:: id()      const { return QStringLiteral("org.kde.okteta.FilterToolView"); }
SidePosition FilterToolViewFactory::defaultPosition() const { return BottomSidePosition; }

AbstractToolView* FilterToolViewFactory::create(AbstractTool* tool) const
{
    return new FilterToolView(qobject_cast<FilterTool*>(tool));
}

}
